@@ -322,87 +322,7 @@ def get_rest_doc(function):
 
     ::
 
-        >>> print(get_rest_doc("ellap"))
-        Let :math:`E` be an :literal:`ell` structure as output by :literal:`ellinit`, defined over
-        a number field...computes the trace of
-        Frobenius :math:`t` for the elliptic curve :math:`E`, defined by the equation :math:`\#E(\mathbb{F}_q)
-        = q+1 - t` (for primes of good reduction).
-        <BLANKLINE>
-        When the characteristic of the finite field is large, the availability of
-        the :literal:`seadata` package will speed the computation.
-        <BLANKLINE>
-        If the curve is defined over :math:`\mathbb{Q}`, :math:`p` must be explicitly given and the
-        function computes the trace of the reduction over :math:`\mathbb{F}_p`.
-        The trace of Frobenius is also the :math:`a_p` coefficient in the curve :math:`L`-series
-        :math:`L(E,s) = \sum_n a_n n^{-s}`, whence the function name. The equation must be
-        integral at :math:`p` but need not be minimal at :math:`p`; of course, a minimal model
-        will be more efficient.
-        ...
-        ::
-        <BLANKLINE>
-            ? E = ellinit([0,1]); \\ y^2 = x^3 + 0.x + 1, defined over Q
-            ? ellap(E, 7) \\ 7 necessary here
-            %2 = -4 \\ #E(F_7) = 7+1-(-4) = 12
-            ? ellcard(E, 7)
-            %3 = 12 \\ OK
-        <BLANKLINE>
-            ? E = ellinit([0,1], 11); \\ defined over F_11
-            ? ellap(E) \\ no need to repeat 11
-            %4 = 0
-            ? ellap(E, 11) \\ ... but it also works
-            %5 = 0
-            ? ellgroup(E, 13) \\ ouch, inconsistent input!
-             *** at top-level: ellap(E,13)
-             *** ^-----------
-             *** ellap: inconsistent moduli in Rg_to_Fp:
-             11
-             13...
-            ? Fq = ffgen(ffinit(11,3), 'a); \\ defines F_q := F_{11^3}
-            ? E = ellinit([a+1,a], Fq); \\ y^2 = x^3 + (a+1)x + a, defined over F_q
-            ? ellap(E)
-            %8 = -3
-        <BLANKLINE>
-        If the curve is defined over a more general number field than :math:`\mathbb{Q}`,
-        the maximal ideal :math:`p` must be explicitly given in :literal:`idealprimedec`
-        format...
-        <BLANKLINE>
-        ::
-        <BLANKLINE>
-            ? K = nfinit(a^2+1); E = ellinit([1+a,0,1,0,0], K);
-            ? fa = idealfactor(K, E.disc)
-            %2 =
-            [ [5, [-2, 1]~, 1, 1, [2, -1; 1, 2]] 1]
-        <BLANKLINE>
-            [[13, [5, 1]~, 1, 1, [-5, -1; 1, -5]] 2]
-            ? ellap(E, fa[1,1])
-            %3 = -1 \\ non-split multiplicative reduction
-            ? ellap(E, fa[2,1])
-            %4 = 1 \\ split multiplicative reduction
-            ? P17 = idealprimedec(K,17)[1];
-            ? ellap(E, P17)
-            %6 = 6 \\ good reduction
-            ? E2 = ellchangecurve(E, [17,0,0,0]);
-            ? ellap(E2, P17)
-            %8 = 6 \\ same, starting from a non-miminal model
-        <BLANKLINE>
-            ? P3 = idealprimedec(K,3)[1];
-            ? E3 = ellchangecurve(E, [3,0,0,0]);
-            ? ellap(E, P3) \\ OK: E is minimal at P3
-            %11 = -2
-            ? ellap(E3, P3) \\ junk: E3 is not minimal at P3 | 3
-            %12 = 0
-        <BLANKLINE>
-        :strong:`Algorithms used.` If :math:`E/\mathbb{F}_q` has CM by a principal imaginary
-        quadratic order we use a fast explicit formula (involving essentially
-        Kronecker symbols and Cornacchia's algorithm), in :math:`O(\log q)^2`.
-        Otherwise, we use Shanks-Mestre's baby-step/giant-step method, which runs in
-        time :math:`~{O}(q^{1/4})` using :math:`~{O}(q^{1/4})` storage, hence becomes
-        unreasonable when :math:`q` has about 30 digits. Above this range, the :literal:`SEA`
-        algorithm becomes available, heuristically in :math:`~{O}(\log q)^4`, and
-        primes of the order of 200 digits become feasible. In small
-        characteristic we use Mestre's (p = 2), Kohel's (p = 3,5,7,13), Satoh-Harley
-        (all in :math:`~{O}(p^{2} n^2)`) or Kedlaya's (in :math:`~{O}(p n^3)`)
-        algorithms.
+        >>> doc = get_rest_doc("ellap")  # doc depends on PARI version
 
     ::
 
