@@ -35,14 +35,18 @@ def pari_share():
 
     EXAMPLES::
 
+        >>> import os
         >>> from autogen.parser import pari_share
-        >>> pari_share().endswith('/share/pari')
+        >>> os.path.isfile(os.path.join(pari_share(), "pari.desc"))
         True
     """
     from subprocess import Popen, PIPE
     if not gppath:
         raise EnvironmentError("cannot find an installation of PARI/GP: make sure that the 'gp' program is in your $PATH")
-    gp = Popen([gppath, "-f", "-q"], stdin=PIPE, stdout=PIPE)
+    # Ignore GP_DATA_DIR environment variable
+    env = dict(os.environ)
+    env.pop("GP_DATA_DIR", None)
+    gp = Popen([gppath, "-f", "-q"], stdin=PIPE, stdout=PIPE, env=env)
     out = gp.communicate(b"print(default(datadir))")[0]
     # Convert out to str if needed
     if not isinstance(out, str):
